Description Usage Arguments Value Author(s) Examples
Compute time and memory usage of R code. WARNING: since memory
usage is measured using free, it includes all running process
(even background processes which are not relevant to the R code,
expr). Memory usage numbers are only interpretable for your R code
when there is constant background process activity on your entire
system!
1 2 3 |
expr |
R code. |
gcFirst |
Run gc before computing initial time/memory values? |
free.file |
file where free output will be written. |
sleep.seconds |
Seconds to wait before/after calling free.profile.start/stop. |
List of time and memory usage.
Toby Dylan Hocking
1 2 3 4 5 6 7 8 9 10 11 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.